@@ -1,23 +1,22 @@
-import datetime
-
 from django.contrib import admin
-from django.db.models import Q
-from django.utils.timezone import now
+from django.db.models import F
+from django.db.models.functions import Coalesce
+from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
-from models import Invoice, InvoiceItem
+from invoicing.models import Invoice, Item
 
 
-class InvoiceItemInline(admin.TabularInline):
+class ItemInline(admin.TabularInline):
     fieldsets = (
         (
             None,
             {
-                'fields': ('title', 'quantity', 'unit', 'unit_price', 'tax_rate', 'weight')
+                'fields': ('title', 'quantity', 'unit', 'unit_price', 'discount', 'tax_rate', 'weight')
             }
         ),
     )
-    model = InvoiceItem
+    model = Item
     extra = 0
 
 
@@ -33,26 +32,27 @@ class OverdueFilter(admin.SimpleListFilter):
 
     def queryset(self, request, queryset):
         if self.value() == 'no':
-            return queryset.filter(Q(date_due__gt=datetime.datetime.combine(now().date(), datetime.time.max))|Q(status=Invoice.STATUS.PAID))
+            return queryset.not_overdue()
         if self.value() == 'yes':
-            return queryset.filter(date_due__lt=datetime.datetime.combine(now().date(), datetime.time.max)).exclude(status=Invoice.STATUS.PAID)
+            return queryset.overdue()
 
 
+@admin.register(Invoice)
 class InvoiceAdmin(admin.ModelAdmin):
     date_hierarchy = 'date_issue'
-    list_display = ['pk', 'type', 'full_number', 'status', 'customer_name', 'customer_country',
-                    'subtotal', 'vat', 'total', 'currency', 'date_issue', 'payment_term', 'is_overdue_boolean', 'is_paid']
+    list_display = ['pk', 'type', 'number', 'status',
+                    'supplier_info', 'customer_info',
+                    'annotated_subtotal', 'vat', 'total',
+                    'currency', 'date_issue', 'payment_term_days', 'is_overdue_boolean', 'is_paid']
     list_editable = ['status']
-    list_filter = ['type', 'status', 'payment_method', OverdueFilter,
-                   #'language', 'currency'
-    ]
+    list_filter = ['type', 'status', 'payment_method', OverdueFilter, 'language', 'currency']
     search_fields = ['number', 'subtitle', 'note', 'supplier_name', 'customer_name', 'shipping_name']
-    inlines = (InvoiceItemInline, )
+    inlines = (ItemInline, )
     fieldsets = (
         (_(u'General information'), {
             'fields': (
-                'type', 'number', 'full_number', 'status', 'subtitle', 'language', 'note',
-                'date_issue', 'date_tax_point', 'date_due', 'date_sent'
+                'type', 'sequence', 'number', 'status', 'subtitle', 'language', 'note',
+                'date_issue', 'date_tax_point', 'date_due', 'date_sent', 'date_paid'
             )
         }),
         (_(u'Contact details'), {
@@ -62,7 +62,7 @@ class InvoiceAdmin(admin.ModelAdmin):
         }),
         (_(u'Payment details'), {
             'fields': (
-                'currency', 'discount', 'credit',
+                'currency', 'credit',
                 #'already_paid',
                 'payment_method', 'constant_symbol', 'variable_symbol', 'specific_symbol', 'reference',
                 'bank_name', 'bank_country', 'bank_city', 'bank_street', 'bank_zip', 'bank_iban', 'bank_swift_bic'
@@ -88,14 +88,31 @@ class InvoiceAdmin(admin.ModelAdmin):
         })
     )
 
+    def get_queryset(self, request):
+        return self.model.objects.annotate(annotated_subtotal=F('total')-Coalesce(F('vat'), 0))
+
+    def annotated_subtotal(self, invoice):
+        return invoice.annotated_subtotal
+    annotated_subtotal.short_description = _(u'subtotal')
+
+    def supplier_info(self, invoice):
+        return mark_safe(u'%s<br>%s' % (invoice.supplier_name, invoice.supplier_country.name))
+    supplier_info.short_description = _(u'supplier')
+
+    def customer_info(self, invoice):
+        return mark_safe(u'%s<br>%s' % (invoice.customer_name, invoice.customer_country.name))
+    customer_info.short_description = _(u'customer')
+
+    def payment_term_days(self, invoice):
+        return u'%s days' % invoice.payment_term
+    payment_term_days.short_description = _(u'payment term')
+
     def is_overdue_boolean(self, invoice):
         return invoice.is_overdue
     is_overdue_boolean.boolean = True
-    is_overdue_boolean.short_description = _(u'Is overdue')
+    is_overdue_boolean.short_description = _(u'is overdue')
 
     def is_paid(self, invoice):
         return invoice.status == Invoice.STATUS.PAID
     is_paid.boolean = True
-    is_paid.short_description = _(u'Is paid')
-
-admin.site.register(Invoice, InvoiceAdmin)
+    is_paid.short_description = _(u'is paid')
